"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mock_1 = __importDefault(require("../../fs/mock"));
const immutable_1 = __importDefault(require("immutable"));
const output_1 = __importDefault(require("../../models/output"));
const book_1 = __importDefault(require("../../models/book"));
const parseBook_1 = __importDefault(require("../../parse/parseBook"));
const preparePlugins_1 = __importDefault(require("../preparePlugins"));
/**
 * Create an output using a generator
 *
 * FOR TESTING PURPOSE ONLY
 *
 * @param {Generator} generator
 * @param {Map<String:String|Map>} files
 * @param {*} [options]
 * @return {Promise<Output>}
 */
function createMockOutput(generator, files, options) {
    const fs = (0, mock_1.default)(files);
    let book = book_1.default.createForFS(fs);
    const state = generator.State ? new generator.State({}) : immutable_1.default.Map();
    book = book.setLogLevel("disabled");
    options = generator.Options(options);
    return (0, parseBook_1.default)(book)
        .then((resultBook) => {
        return new output_1.default({
            book: resultBook,
            options: options,
            state: state,
            generator: generator.name,
        });
    })
        .then(preparePlugins_1.default);
}
exports.default = createMockOutput;
