"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const parseStructureFile_1 = __importDefault(require("./parseStructureFile"));
const readme_1 = __importDefault(require("../models/readme"));
const error_1 = __importDefault(require("../utils/error"));
/**
 Parse readme from book

 @param {Book} book
 @return {Promise<Book>}
 */
function parseReadme(book) {
    const logger = book.getLogger();
    return (0, parseStructureFile_1.default)(book, "readme").spread((file, result) => {
        if (!file) {
            throw new error_1.default.FileNotFoundError({ filename: "README" });
        }
        logger.debug.ln("readme found at", file.getPath());
        const readme = readme_1.default.create(file, result);
        return book.set("readme", readme);
    });
}
exports.default = parseReadme;
