"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const immutable_1 = __importDefault(require("immutable"));
const parsers_1 = __importDefault(require("../parsers"));
/**
 * Return a list of all shortcuts that can apply
 * to a file for a TemplatEngine
 *
 * @param {List<TemplateBlock>} engine
 * @param {string} filePath
 * @return {List<TemplateShortcut>}
 */
function listShortcuts(blocks, filePath) {
    const parser = parsers_1.default.getForFile(filePath);
    if (!parser) {
        return immutable_1.default.List();
    }
    return blocks
        .map((block) => {
        return block.getShortcuts();
    })
        .filter((shortcuts) => {
        return shortcuts && shortcuts.acceptParser(parser.getName());
    });
}
exports.default = listShortcuts;
